[![Build Status](https://dev.azure.com/cmsj/cmsj/_apis/build/status/cmsj.prometheus-bugzilla-exporter)](https://dev.azure.com/cmsj/cmsj/_build/latest?definitionId=2)

# prometheus-bugzilla-exporter

This exports data from Bugzilla 5 in a format Prometheus can ingest.
